FluentDateTime class

A FluentType representing a date and time.

Inheritance

Constructors

FluentDateTime(DateTime value, {String? locale, String? pattern, String? calendar, String? numberingSystem, String? timeZone, bool? hour12, String? weekday, String? era, String? year, String? month, String? day, String? hour, String? minute, String? second, String? timeZoneName})

Properties

calendar String?
getter/setter pair
day String?
getter/setter pair
era String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hour String?
getter/setter pair
hour12 bool?
getter/setter pair
locale String?
getter/setter pair
minute String?
getter/setter pair
month String?
getter/setter pair
numberingSystem String?
getter/setter pair
pattern String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
second String?
getter/setter pair
timeZone String?
getter/setter pair
timeZoneName String?
getter/setter pair
value DateTime
getter/setter pairinherited
weekday String?
getter/setter pair
year String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited